#!/bin/sh

# This helper script will handle deploying a s3 bucket
set -e

source /scripts/utils.sh
source /scripts/terraform.sh

if [ -z "${queueName}" ]; then
  echo "Must set env QueueName"
  exit 1
fi


check_access ${appsNamespace} configmaps

tfAdditionalVarsFile=${tfRoot}/additional_settings.auto.tfvars

echo "iam_policy_prefix = \"${externalNamingPrefix}\"" >> ${tfAdditionalVarsFile}

terraform_init
terraform_plan
terraform_apply
terraform_output

print_header "Dump output to ConfigMap"
arnConfigMapName=${namingPrefix}-arn
terraform_get arn arnValue
terraform_get url urlValue
terraform_get arn_dlq arnDLQValue
terraform_get url_dlq urlDLQValue
terraform_get consumer_policy consumerPolicy
terraform_get producer_policy producerPolicy

cat >/tmp/config.yaml <<EOF
apiVersion: v1
kind: ConfigMap
metadata:
  name: ${arnConfigMapName}
data:
  ARN: ${arnValue}
  URL: ${urlValue}
  ARN_DLQ: ${arnDLQValue}
  URL_DLQ: ${urlDLQValue}
  ConsumerPolicy: ${consumerPolicy}
  ProducerPolicy: ${producerPolicy}
EOF

run_cmd cat "/tmp/config.yaml"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} apply -f /tmp/config.yaml
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${infraNamespace} apply -f /tmp/config.yaml

echo "Config map ${arnConfigMapName}"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} get cm ${arnConfigMapName} -o yaml

cprint "$0 done "
